Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(997)

Unified Diff: media/filters/ffmpeg_glue_unittest.cc

Issue 165176: Merge 21999 - BufferedDataSource to support server without range request supp... (Closed) Base URL: svn://chrome-svn/chrome/branches/195/src/
Patch Set: Created 11 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/filters/ffmpeg_glue.cc ('k') | media/filters/file_data_source.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/filters/ffmpeg_glue_unittest.cc
===================================================================
--- media/filters/ffmpeg_glue_unittest.cc (revision 22811)
+++ media/filters/ffmpeg_glue_unittest.cc (working copy)
@@ -26,7 +26,7 @@
MOCK_METHOD1(GetPosition, bool(int64* position_out));
MOCK_METHOD1(SetPosition, bool(int64 position));
MOCK_METHOD1(GetSize, bool(int64* size_out));
- MOCK_METHOD0(IsStreamed, bool());
+ MOCK_METHOD0(IsStreaming, bool());
private:
DISALLOW_COPY_AND_ASSIGN(MockProtocol);
@@ -45,8 +45,8 @@
// Helper to open a URLContext pointing to the given mocked protocol.
// Callers are expected to close the context at the end of their test.
virtual void OpenContext(MockProtocol* protocol, URLContext* context) {
- // IsStreamed() is called when opening.
- EXPECT_CALL(*protocol, IsStreamed()).WillOnce(Return(true));
+ // IsStreaming() is called when opening.
+ EXPECT_CALL(*protocol, IsStreaming()).WillOnce(Return(true));
// Add the protocol to the glue layer and open a context.
std::string key = FFmpegGlue::get()->AddProtocol(protocol);
@@ -144,7 +144,7 @@
// Create our protocol and add them to the glue layer.
scoped_ptr<StrictMock<Destroyable<MockProtocol> > > protocol(
new StrictMock<Destroyable<MockProtocol> >());
- EXPECT_CALL(*protocol, IsStreamed()).WillOnce(Return(true));
+ EXPECT_CALL(*protocol, IsStreaming()).WillOnce(Return(true));
std::string key = glue->AddProtocol(protocol.get());
// Prepare FFmpeg URLContext structure.
Property changes on: media\filters\ffmpeg_glue_unittest.cc
___________________________________________________________________
Modified: svn:mergeinfo
Merged /trunk/src/media/filters/ffmpeg_glue_unittest.cc:r21999
« no previous file with comments | « media/filters/ffmpeg_glue.cc ('k') | media/filters/file_data_source.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698